# projecc
A small simple package for projecting orbital elements onto sky plane and vice versa

## Change log

#### Jan 27, 2025:
1.1.0 Added classes and funtions for predicting the position of a planet in the sky plane at a given time

#### Oct 14, 2024:
1.0.1 Fixed coordinate system in sep/pa functions

#### Oct 11, 2024:
1.0.1 Fixed coordinate system in KeplerianToCartesian and added Sirius example to notebook

#### Oct 30, 2023:
1.0.0 Initial release
